"""Converts the samples from the board to a VCD file for sigrok.

Usage:
   python3 tovcd.py < /dev/ttyUSB0 | tee log.vcd
"""

import datetime
import sys

_HEADER = """
$date {date} $end
$version juju.nz tovcd.py $end
$timescale 1 us $end
$scope module libsigrok $end
"""

_MID = """
$upscope $end
$enddefinitions $end
"""

_IDS = "!#$%&'()"


def main():
    print(_HEADER.strip().format(date=datetime.datetime.now()))

    for wire in range(2):
        print(f"$var wire 1 {_IDS[wire]} D{wire} $end")

    print(_MID.strip())

    now = 0
    last_d = None

    for ch in sys.stdin.read():
        ch = ord(ch) - 32
        for i in range(3):
            now += 1
            d = (ch >> 5) & 1, (ch >> 4) & 1
            ch <<= 2
            if d != last_d:
                parts = (f"{x}{_IDS[i]}" for i, x in enumerate(d))
                print(f"#{now}", " ".join(parts))
                last_d = d


if __name__ == "__main__":
    main()
